==> aliyun-python-sdk-r-kvstore-2.0.5.tar.gz: aliyun-python-sdk-r-kvstore-2.0.5/aliyunsdkr_kvstore/request/v20150101/UntagResourcesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class UntagResourcesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'R-kvstore', '2015-01-01', 'UntagResources','redisa')

	def get_ResourceId47(self):
		return self.get_query_params().get('ResourceId.47')

	def set_ResourceId47(self,ResourceId47):
		self.add_query_param('ResourceId.47',ResourceId47)

	def get_ResourceId48(self):
		return self.get_query_params().get('ResourceId.48')

	def set_ResourceId48(self,ResourceId48):
		self.add_query_param('ResourceId.48',ResourceId48)

	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_ResourceId49(self):
		return self.get_query_params().get('ResourceId.49')

	def set_ResourceId49(self,ResourceId49):
		self.add_query_param('ResourceId.49',ResourceId49)

	def get_ResourceId40(self):
		return self.get_query_params().get('ResourceId.40')

	def set_ResourceId40(self,ResourceId40):
		self.add_query_param('ResourceId.40',ResourceId40)

	def get_ResourceId41(self):
		return self.get_query_params().get('ResourceId.41')

	def set_ResourceId41(self,ResourceId41):
		self.add_query_param('ResourceId.41',ResourceId41)

	def get_ResourceId42(self):
		return self.get_query_params().get('ResourceId.42')

	def set_ResourceId42(self,ResourceId42):
		self.add_query_param('ResourceId.42',ResourceId42)

	def get_TagKey9(self):
		return self.get_query_params().get('TagKey.9')

	def set_TagKey9(self,TagKey9):
		self.add_query_param('TagKey.9',TagKey9)

	def get_ResourceId1(self):
		return self.get_query_params().get('ResourceId.1')

	def set_ResourceId1(self,ResourceId1):
		self.add_query_param('ResourceId.1',ResourceId1)

	def get_ResourceId43(self):
		return self.get_query_params().get('ResourceId.43')

	def set_ResourceId43(self,ResourceId43):
		self.add_query_param('ResourceId.43',ResourceId43)

	def get_ResourceId2(self):
		return self.get_query_params().get('ResourceId.2')

	def set_ResourceId2(self,ResourceId2):
		self.add_query_param('ResourceId.2',ResourceId2)

	def get_ResourceId44(self):
		return self.get_query_params().get('ResourceId.44')

	def set_ResourceId44(self,ResourceId44):
		self.add_query_param('ResourceId.44',ResourceId44)

	def get_ResourceId3(self):
		return self.get_query_params().get('ResourceId.3')

	def set_ResourceId3(self,ResourceId3):
		self.add_query_param('ResourceId.3',ResourceId3)

	def get_ResourceId45(self):
		return self.get_query_params().get('ResourceId.45')

	def set_ResourceId45(self,ResourceId45):
		self.add_query_param('ResourceId.45',ResourceId45)

	def get_ResourceId4(self):
		return self.get_query_params().get('ResourceId.4')

	def set_ResourceId4(self,ResourceId4):
		self.add_query_param('ResourceId.4',ResourceId4)

	def get_ResourceId46(self):
		return self.get_query_params().get('ResourceId.46')

	def set_ResourceId46(self,ResourceId46):
		self.add_query_param('ResourceId.46',ResourceId46)

	def get_ResourceId5(self):
		return self.get_query_params().get('ResourceId.5')

	def set_ResourceId5(self,ResourceId5):
		self.add_query_param('ResourceId.5',ResourceId5)

	def get_TagKey4(self):
		return self.get_query_params().get('TagKey.4')

	def set_TagKey4(self,TagKey4):
		self.add_query_param('TagKey.4',TagKey4)

	def get_ResourceId6(self):
		return self.get_query_params().get('ResourceId.6')

	def set_ResourceId6(self,ResourceId6):
		self.add_query_param('ResourceId.6',ResourceId6)

	def get_TagKey3(self):
		return self.get_query_params().get('TagKey.3')

	def set_TagKey3(self,TagKey3):
		self.add_query_param('TagKey.3',TagKey3)

	def get_ResourceId7(self):
		return self.get_query_params().get('ResourceId.7')

	def set_ResourceId7(self,ResourceId7):
		self.add_query_param('ResourceId.7',ResourceId7)

	def get_TagKey2(self):
		return self.get_query_params().get('TagKey.2')

	def set_TagKey2(self,TagKey2):
		self.add_query_param('TagKey.2',TagKey2)

	def get_ResourceId8(self):
		return self.get_query_params().get('ResourceId.8')

	def set_ResourceId8(self,ResourceId8):
		self.add_query_param('ResourceId.8',ResourceId8)

	def get_TagKey1(self):
		return self.get_query_params().get('TagKey.1')

	def set_TagKey1(self,TagKey1):
		self.add_query_param('TagKey.1',TagKey1)

	def get_ResourceId9(self):
		return self.get_query_params().get('ResourceId.9')

	def set_ResourceId9(self,ResourceId9):
		self.add_query_param('ResourceId.9',ResourceId9)

	def get_TagKey8(self):
		return self.get_query_params().get('TagKey.8')

	def set_TagKey8(self,TagKey8):
		self.add_query_param('TagKey.8',TagKey8)

	def get_TagKey20(self):
		return self.get_query_params().get('TagKey.20')

	def set_TagKey20(self,TagKey20):
		self.add_query_param('TagKey.20',TagKey20)

	def get_SecurityToken(self):
		return self.get_query_params().get('SecurityToken')

	def set_SecurityToken(self,SecurityToken):
		self.add_query_param('SecurityToken',SecurityToken)

	def get_TagKey7(self):
		return self.get_query_params().get('TagKey.7')

	def set_TagKey7(self,TagKey7):
		self.add_query_param('TagKey.7',TagKey7)

	def get_TagKey6(self):
		return self.get_query_params().get('TagKey.6')

	def set_TagKey6(self,TagKey6):
		self.add_query_param('TagKey.6',TagKey6)

	def get_TagKey5(self):
		return self.get_query_params().get('TagKey.5')

	def set_TagKey5(self,TagKey5):
		self.add_query_param('TagKey.5',TagKey5)

	def get_ResourceId36(self):
		return self.get_query_params().get('ResourceId.36')

	def set_ResourceId36(self,ResourceId36):
		self.add_query_param('ResourceId.36',ResourceId36)

	def get_ResourceId37(self):
		return self.get_query_params().get('ResourceId.37')

	def set_ResourceId37(self,ResourceId37):
		self.add_query_param('ResourceId.37',ResourceId37)

	def get_ResourceId38(self):
		return self.get_query_params().get('ResourceId.38')

	def set_ResourceId38(self,ResourceId38):
		self.add_query_param('ResourceId.38',ResourceId38)

	def get_ResourceId39(self):
		return self.get_query_params().get('ResourceId.39')

	def set_ResourceId39(self,ResourceId39):
		self.add_query_param('ResourceId.39',ResourceId39)

	def get_ResourceId30(self):
		return self.get_query_params().get('ResourceId.30')

	def set_ResourceId30(self,ResourceId30):
		self.add_query_param('ResourceId.30',ResourceId30)

	def get_ResourceId31(self):
		return self.get_query_params().get('ResourceId.31')

	def set_ResourceId31(self,ResourceId31):
		self.add_query_param('ResourceId.31',ResourceId31)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_ResourceId32(self):
		return self.get_query_params().get('ResourceId.32')

	def set_ResourceId32(self,ResourceId32):
		self.add_query_param('ResourceId.32',ResourceId32)

	def get_ResourceId33(self):
		return self.get_query_params().get('ResourceId.33')

	def set_ResourceId33(self,ResourceId33):
		self.add_query_param('ResourceId.33',ResourceId33)

	def get_ResourceId34(self):
		return self.get_query_params().get('ResourceId.34')

	def set_ResourceId34(self,ResourceId34):
		self.add_query_param('ResourceId.34',ResourceId34)

	def get_ResourceId35(self):
		return self.get_query_params().get('ResourceId.35')

	def set_ResourceId35(self,ResourceId35):
		self.add_query_param('ResourceId.35',ResourceId35)

	def get_ResourceId25(self):
		return self.get_query_params().get('ResourceId.25')

	def set_ResourceId25(self,ResourceId25):
		self.add_query_param('ResourceId.25',ResourceId25)

	def get_ResourceId26(self):
		return self.get_query_params().get('ResourceId.26')

	def set_ResourceId26(self,ResourceId26):
		self.add_query_param('ResourceId.26',ResourceId26)

	def get_ResourceId27(self):
		return self.get_query_params().get('ResourceId.27')

	def set_ResourceId27(self,ResourceId27):
		self.add_query_param('ResourceId.27',ResourceId27)

	def get_ResourceId28(self):
		return self.get_query_params().get('ResourceId.28')

	def set_ResourceId28(self,ResourceId28):
		self.add_query_param('ResourceId.28',ResourceId28)

	def get_ResourceId29(self):
		return self.get_query_params().get('ResourceId.29')

	def set_ResourceId29(self,ResourceId29):
		self.add_query_param('ResourceId.29',ResourceId29)

	def get_ResourceId20(self):
		return self.get_query_params().get('ResourceId.20')

	def set_ResourceId20(self,ResourceId20):
		self.add_query_param('ResourceId.20',ResourceId20)

	def get_ResourceId21(self):
		return self.get_query_params().get('ResourceId.21')

	def set_ResourceId21(self,ResourceId21):
		self.add_query_param('ResourceId.21',ResourceId21)

	def get_ResourceId22(self):
		return self.get_query_params().get('ResourceId.22')

	def set_ResourceId22(self,ResourceId22):
		self.add_query_param('ResourceId.22',ResourceId22)

	def get_ResourceId23(self):
		return self.get_query_params().get('ResourceId.23')

	def set_ResourceId23(self,ResourceId23):
		self.add_query_param('ResourceId.23',ResourceId23)

	def get_ResourceId24(self):
		return self.get_query_params().get('ResourceId.24')

	def set_ResourceId24(self,ResourceId24):
		self.add_query_param('ResourceId.24',ResourceId24)

	def get_Scope(self):
		return self.get_query_params().get('Scope')

	def set_Scope(self,Scope):
		self.add_query_param('Scope',Scope)

	def get_ResourceId14(self):
		return self.get_query_params().get('ResourceId.14')

	def set_ResourceId14(self,ResourceId14):
		self.add_query_param('ResourceId.14',ResourceId14)

	def get_ResourceId15(self):
		return self.get_query_params().get('ResourceId.15')

	def set_ResourceId15(self,ResourceId15):
		self.add_query_param('ResourceId.15',ResourceId15)

	def get_ResourceId16(self):
		return self.get_query_params().get('ResourceId.16')

	def set_ResourceId16(self,ResourceId16):
		self.add_query_param('ResourceId.16',ResourceId16)

	def get_TagKey19(self):
		return self.get_query_params().get('TagKey.19')

	def set_TagKey19(self,TagKey19):
		self.add_query_param('TagKey.19',TagKey19)

	def get_ResourceId17(self):
		return self.get_query_params().get('ResourceId.17')

	def set_ResourceId17(self,ResourceId17):
		self.add_query_param('ResourceId.17',ResourceId17)

	def get_TagKey18(self):
		return self.get_query_params().get('TagKey.18')

	def set_TagKey18(self,TagKey18):
		self.add_query_param('TagKey.18',TagKey18)

	def get_ResourceId18(self):
		return self.get_query_params().get('ResourceId.18')

	def set_ResourceId18(self,ResourceId18):
		self.add_query_param('ResourceId.18',ResourceId18)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_ResourceId19(self):
		return self.get_query_params().get('ResourceId.19')

	def set_ResourceId19(self,ResourceId19):
		self.add_query_param('ResourceId.19',ResourceId19)

	def get_OwnerAccount(self):
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self,OwnerAccount):
		self.add_query_param('OwnerAccount',OwnerAccount)

	def get_ResourceId50(self):
		return self.get_query_params().get('ResourceId.50')

	def set_ResourceId50(self,ResourceId50):
		self.add_query_param('ResourceId.50',ResourceId50)

	def get_ResourceId10(self):
		return self.get_query_params().get('ResourceId.10')

	def set_ResourceId10(self,ResourceId10):
		self.add_query_param('ResourceId.10',ResourceId10)

	def get_ResourceType(self):
		return self.get_query_params().get('ResourceType')

	def set_ResourceType(self,ResourceType):
		self.add_query_param('ResourceType',ResourceType)

	def get_ResourceId11(self):
		return self.get_query_params().get('ResourceId.11')

	def set_ResourceId11(self,ResourceId11):
		self.add_query_param('ResourceId.11',ResourceId11)

	def get_ResourceId12(self):
		return self.get_query_params().get('ResourceId.12')

	def set_ResourceId12(self,ResourceId12):
		self.add_query_param('ResourceId.12',ResourceId12)

	def get_ResourceId13(self):
		return self.get_query_params().get('ResourceId.13')

	def set_ResourceId13(self,ResourceId13):
		self.add_query_param('ResourceId.13',ResourceId13)

	def get_TagKey13(self):
		return self.get_query_params().get('TagKey.13')

	def set_TagKey13(self,TagKey13):
		self.add_query_param('TagKey.13',TagKey13)

	def get_TagKey12(self):
		return self.get_query_params().get('TagKey.12')

	def set_TagKey12(self,TagKey12):
		self.add_query_param('TagKey.12',TagKey12)

	def get_TagKey11(self):
		return self.get_query_params().get('TagKey.11')

	def set_TagKey11(self,TagKey11):
		self.add_query_param('TagKey.11',TagKey11)

	def get_TagKey10(self):
		return self.get_query_params().get('TagKey.10')

	def set_TagKey10(self,TagKey10):
		self.add_query_param('TagKey.10',TagKey10)

	def get_TagKey17(self):
		return self.get_query_params().get('TagKey.17')

	def set_TagKey17(self,TagKey17):
		self.add_query_param('TagKey.17',TagKey17)

	def get_TagKey16(self):
		return self.get_query_params().get('TagKey.16')

	def set_TagKey16(self,TagKey16):
		self.add_query_param('TagKey.16',TagKey16)

	def get_TagKey15(self):
		return self.get_query_params().get('TagKey.15')

	def set_TagKey15(self,TagKey15):
		self.add_query_param('TagKey.15',TagKey15)

	def get_TagKey14(self):
		return self.get_query_params().get('TagKey.14')

	def set_TagKey14(self,TagKey14):
		self.add_query_param('TagKey.14',TagKey14)

==> aliyun-python-sdk-r-kvstore-2.0.6.tar.gz: aliyun-python-sdk-r-kvstore-2.0.6/aliyunsdkr_kvstore/request/v20150101/UntagResourcesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class UntagResourcesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'R-kvstore', '2015-01-01', 'UntagResources','R-kvstore')

	def get_All(self):
		return self.get_query_params().get('All')

	def set_All(self,All):
		self.add_query_param('All',All)

	def get_ResourceOwnerId(self):
		return self.get_query_params().get('ResourceOwnerId')

	def set_ResourceOwnerId(self,ResourceOwnerId):
		self.add_query_param('ResourceOwnerId',ResourceOwnerId)

	def get_ResourceIds(self):
		return self.get_query_params().get('ResourceIds')

	def set_ResourceIds(self,ResourceIds):
		for i in range(len(ResourceIds)):	
			if ResourceIds[i] is not None:
				self.add_query_param('ResourceId.' + str(i + 1) , ResourceIds[i]);

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_OwnerAccount(self):
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self,OwnerAccount):
		self.add_query_param('OwnerAccount',OwnerAccount)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

	def get_TagKeys(self):
		return self.get_query_params().get('TagKeys')

	def set_TagKeys(self,TagKeys):
		for i in range(len(TagKeys)):	
			if TagKeys[i] is not None:
				self.add_query_param('TagKey.' + str(i + 1) , TagKeys[i]);

	def get_ResourceType(self):
		return self.get_query_params().get('ResourceType')

	def set_ResourceType(self,ResourceType):
		self.add_query_param('ResourceType',ResourceType)
